@@ -232,11 +232,11 @@ int get_num_procs(void);
 #else
 int get_num_procs(void) {
   static int nums = 0;
-
+  int ret;
 #if defined(__GLIBC_PREREQ)
   cpu_set_t cpuset,*cpusetp;
   size_t size;
-  int ret;
+
 #if !__GLIBC_PREREQ(2, 7)
   int i;
 #if !__GLIBC_PREREQ(2, 6)
@@ -246,20 +246,32 @@ int get_num_procs(void) {
 #endif
 
   if (!nums) nums = sysconf(_SC_NPROCESSORS_CONF);
+
+#if defined(USE_OPENMP)
+#if _OPENMP >= 201511
+    int i,n;
+    n = 0;
+    ret = omp_get_num_places();
+    if (ret > 0) for (i=0; i<ret;i++) n+= omp_get_place_num_procs(i);
+    if (n > 0) nums = n;
+#endif
+    return (nums > 0 ? nums : 2);
+#endif
+
 #if !defined(OS_LINUX)
-  return nums;
+  return (nums > 0 ? nums : 2);
 #endif
 
 #if !defined(__GLIBC_PREREQ)
-  return nums;
+  return (nums > 0 ? nums :2);
 #else
  #if !__GLIBC_PREREQ(2, 3)
-  return nums;
+  return (nums > 0 ? nums :2);
  #endif
 
  #if !__GLIBC_PREREQ(2, 7)
   ret = sched_getaffinity(0,sizeof(cpuset), &cpuset);
-  if (ret!=0) return nums;
+  if (ret!=0) return (nums > 0 ? nums :2);
   n=0;
   #if !__GLIBC_PREREQ(2, 6)
   for (i=0;i<nums;i++)
@@ -268,31 +280,31 @@ int get_num_procs(void) {
   #else
   nums = CPU_COUNT(sizeof(cpuset),&cpuset);
   #endif
-  return nums;
+  return (nums > 0 ? nums :2);
  #else
   if (nums >= CPU_SETSIZE) {
     cpusetp = CPU_ALLOC(nums);
       if (cpusetp == NULL) {
-        return nums;
+        return (nums > 0 ? nums :2);
       }
     size = CPU_ALLOC_SIZE(nums);
     ret = sched_getaffinity(0,size,cpusetp);
     if (ret!=0) {
       CPU_FREE(cpusetp);
-      return nums;
+      return (nums > 0 ? nums :2);
     }
     ret = CPU_COUNT_S(size,cpusetp);
     if (ret > 0 && ret < nums) nums = ret;
     CPU_FREE(cpusetp);
-    return nums;
+    return (nums > 0 ? nums :2);
   } else {
     ret = sched_getaffinity(0,sizeof(cpuset),&cpuset);
     if (ret!=0) {
-      return nums;
+      return (nums > 0 ? nums :2);
     }
     ret = CPU_COUNT(&cpuset);
     if (ret > 0 && ret < nums) nums = ret;
-    return nums;
+    return (nums > 0 ? nums :2);
   }
  #endif
 #endif
@@ -410,6 +422,8 @@ This value is equal or large than blas_cpu_number. This means some threads are s
 */
 int blas_num_threads = 0;
 
+int blas_num_threads_set = 0;
+
 int  goto_get_num_procs  (void) {
   return blas_cpu_number;
 }
@@ -1792,11 +1806,12 @@ int get_num_procs(void);
 int get_num_procs(void) {
 
   static int nums = 0;
-
+  int ret;
+	
 #if defined(__GLIBC_PREREQ)
   cpu_set_t cpuset,*cpusetp;
   size_t size;
-  int ret;
+
 #if !__GLIBC_PREREQ(2, 7)
   int i;
 #if !__GLIBC_PREREQ(2, 6)
@@ -1806,53 +1821,66 @@ int get_num_procs(void) {
 #endif
 
   if (!nums) nums = sysconf(_SC_NPROCESSORS_CONF);
-#if !defined(OS_LINUX)
-  return nums;
+
+#if defined(USE_OPENMP)
+/*  if (omp_get_proc_bind() != omp_proc_bind_false) */
+#if _OPENMP >= 201511
+    int i,n;
+    n = 0;
+    ret = omp_get_num_places();
+    if (ret > 0) for (i=0;i<ret;i++) n+= omp_get_place_num_procs(i);
+    if (n > 0) nums = n;
+#endif
+    return (nums > 0 ? nums :2);
 #endif
 
+#if !defined(OS_LINUX)
+  return (nums > 0 ? nums :2);
+#endif
+	
 #if !defined(__GLIBC_PREREQ)
-  return nums;
+  return (nums > 0 ? nums :2);
 #else
  #if !__GLIBC_PREREQ(2, 3)
-  return nums;
+  return (nums > 0 ? nums :2);
  #endif
 
  #if !__GLIBC_PREREQ(2, 7)
   ret = sched_getaffinity(0,sizeof(cpuset), &cpuset);
-  if (ret!=0) return nums;
+  if (ret!=0) return (nums > 0 ? nums :2);
   n=0;
   #if !__GLIBC_PREREQ(2, 6)
-  for (i=0;i<nums;i++)
+  for (i=0;i<(nums > 0 ? nums :2);i++)
      if (CPU_ISSET(i,&cpuset)) n++;
   nums=n;
   #else
   nums = CPU_COUNT(sizeof(cpuset),&cpuset);
   #endif
-  return nums;
+  return (nums > 0 ? nums :2);
  #else
   if (nums >= CPU_SETSIZE) {
     cpusetp = CPU_ALLOC(nums);
       if (cpusetp == NULL) {
-        return nums;
+        return (nums > 0 ? nums :2);
       }
     size = CPU_ALLOC_SIZE(nums);
     ret = sched_getaffinity(0,size,cpusetp);
     if (ret!=0) {
       CPU_FREE(cpusetp);
-      return nums;
+      return (nums > 0 ? nums :2);
     }
     ret = CPU_COUNT_S(size,cpusetp);
     if (ret > 0 && ret < nums) nums = ret;
     CPU_FREE(cpusetp);
-    return nums;
+    return (nums > 0 ? nums :2);
   } else {
     ret = sched_getaffinity(0,sizeof(cpuset),&cpuset);
     if (ret!=0) {
-      return nums;
+      return (nums > 0 ? nums :2);
     }
     ret = CPU_COUNT(&cpuset);
     if (ret > 0 && ret < nums) nums = ret;
-    return nums;
+    return (nums > 0 ? nums :2);
   }
  #endif
 #endif
@@ -1968,6 +1996,8 @@ This value is equal or large than blas_cpu_number. This means some threads are s
 */
 int blas_num_threads = 0;
 
+int blas_num_threads_set = 0;
+
 int  goto_get_num_procs  (void) {
   return blas_cpu_number;
 }
@@ -2854,32 +2884,28 @@ void *blas_memory_alloc(int procpos){
     position ++;
 
   } while (position < NUM_BUFFERS);
-#if (defined(SMP) || defined(USE_LOCKING)) && !defined(USE_OPENMP)
-  UNLOCK_COMMAND(&alloc_lock);
-#endif
+
   if (memory_overflowed) {
-#if (defined(SMP) || defined(USE_LOCKING)) && !defined(USE_OPENMP)
-  LOCK_COMMAND(&alloc_lock);
-#endif
-  do {
-    RMB;
+
+    do {
+      RMB;
 #if defined(USE_OPENMP)
-    if (!newmemory[position-NUM_BUFFERS].used) {
-      blas_lock(&newmemory[position-NUM_BUFFERS].lock);
+      if (!newmemory[position-NUM_BUFFERS].used) {
+        blas_lock(&newmemory[position-NUM_BUFFERS].lock);
 #endif
-      if (!newmemory[position-NUM_BUFFERS].used) goto allocation2;
+        if (!newmemory[position-NUM_BUFFERS].used) goto allocation2;
 
 #if defined(USE_OPENMP)
-      blas_unlock(&newmemory[position-NUM_BUFFERS].lock);
-    }
+        blas_unlock(&newmemory[position-NUM_BUFFERS].lock);
+      }
 #endif
-    position ++;
+      position ++;
 
-  } while (position < 512+NUM_BUFFERS);
+    } while (position < 512+NUM_BUFFERS);
+  }
 #if (defined(SMP) || defined(USE_LOCKING)) && !defined(USE_OPENMP)
   UNLOCK_COMMAND(&alloc_lock);
 #endif
-} 
   goto error;
 
   allocation :
@@ -2904,7 +2930,7 @@ void *blas_memory_alloc(int procpos){
 
       func = &memoryalloc[0];
 
-      while ((func != NULL) && (map_address == (void *) -1)) {
+      while ((*func != NULL) && (map_address == (void *) -1)) {
 
         map_address = (*func)((void *)base_address);
 
@@ -2984,6 +3010,9 @@ void *blas_memory_alloc(int procpos){
   return (void *)memory[position].addr;
 
  error:
+#if (defined(SMP) || defined(USE_LOCKING)) && !defined(USE_OPENMP)
+  LOCK_COMMAND(&alloc_lock);
+#endif
  if (memory_overflowed) goto terminate;
   fprintf(stderr,"OpenBLAS warning: precompiled NUM_THREADS exceeded, adding auxiliary array for thread metadata.\n");
   memory_overflowed=1;
@@ -2997,7 +3026,6 @@ void *blas_memory_alloc(int procpos){
   newmemory[i].used   = 0;
   newmemory[i].lock   = 0;
 }
-  newmemory[position-NUM_BUFFERS].used = 1;
   
 allocation2:
   newmemory[position-NUM_BUFFERS].used = 1;
@@ -3015,7 +3043,7 @@ allocation2:
 
       func = &memoryalloc[0];
 
-      while ((func != NULL) && (map_address == (void *) -1)) {
+      while ((*func != NULL) && (map_address == (void *) -1)) {
 
         map_address = (*func)((void *)base_address);
 
@@ -3069,6 +3097,9 @@ allocation2:
   return (void *)newmemory[position-NUM_BUFFERS].addr;
 
 terminate:
+#if (defined(SMP) || defined(USE_LOCKING)) && !defined(USE_OPENMP)
+    UNLOCK_COMMAND(&alloc_lock);
+#endif
   printf("OpenBLAS : Program is Terminated. Because you tried to allocate too many memory regions.\n");
   printf("This library was built to support a maximum of %d threads - either rebuild OpenBLAS\n", NUM_BUFFERS);
   printf("with a larger NUM_THREADS value or set the environment variable OPENBLAS_NUM_THREADS to\n");
