@@ -631,7 +631,7 @@ f"> */
 /* > \endverbatim */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int ztptri_(char *uplo, char *diag, integer *n, 
+/* Subroutine */ void ztptri_(char *uplo, char *diag, integer *n, 
 	doublecomplex *ap, integer *info)
 {
     /* System generated locals */
@@ -641,10 +641,10 @@ f"> */
     /* Local variables */
     integer j;
     extern logical lsame_(char *, char *);
-    extern /* Subroutine */ int zscal_(integer *, doublecomplex *, 
+    extern /* Subroutine */ void zscal_(integer *, doublecomplex *, 
 	    doublecomplex *, integer *);
     logical upper;
-    extern /* Subroutine */ int ztpmv_(char *, char *, char *, integer *, 
+    extern /* Subroutine */ void ztpmv_(char *, char *, char *, integer *, 
 	    doublecomplex *, doublecomplex *, integer *);
     integer jc, jj;
     extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen);
@@ -681,7 +681,7 @@ f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("ZTPTRI", &i__1, (ftnlen)6);
-	return 0;
+	return;
     }
 
 /*     Check for singularity if non-unit. */
@@ -694,7 +694,7 @@ f"> */
 		jj += *info;
 		i__2 = jj;
 		if (ap[i__2].r == 0. && ap[i__2].i == 0.) {
-		    return 0;
+		    return;
 		}
 /* L10: */
 	    }
@@ -704,7 +704,7 @@ f"> */
 	    for (*info = 1; *info <= i__1; ++(*info)) {
 		i__2 = jj;
 		if (ap[i__2].r == 0. && ap[i__2].i == 0.) {
-		    return 0;
+		    return;
 		}
 		jj = jj + *n - *info + 1;
 /* L20: */
@@ -776,7 +776,7 @@ f"> */
 	}
     }
 
-    return 0;
+    return;
 
 /*     End of ZTPTRI */
 
